@@ -19,7 +19,12 @@ class _Properties(UserDict):
 
     def __setitem__(self, key, value):
         super(_Properties, self).__setitem__(key, value)
-        import taipy.core.taipy as tp
+        import taipy.core as tp
 
         if hasattr(self, "parent"):
             tp.set(self.parent)
+
+    def __getitem__(self, key):
+        from taipy.core.config._config_template_handler import _ConfigTemplateHandler as _tpl
+
+        return _tpl._replace_templates(super(_Properties, self).__getitem__(key))
